@@ -61,13 +61,13 @@ class LunarTime:
         return LunarUtil.POSITION_DESC[self.getPositionCai()]
 
     def getChong(self):
-        return LunarUtil.CHONG[self.__zhiIndex + 1]
+        return LunarUtil.CHONG[self.__zhiIndex]
 
     def getChongGan(self):
-        return LunarUtil.CHONG_GAN[self.__ganIndex + 1]
+        return LunarUtil.CHONG_GAN[self.__ganIndex]
 
     def getChongGanTie(self):
-        return LunarUtil.CHONG_GAN_TIE[self.getGan()]
+        return LunarUtil.CHONG_GAN_TIE[self.__ganIndex]
 
     def getChongShengXiao(self):
         chong = self.getChong()
@@ -161,7 +161,7 @@ class LunarTime:
             return "00:00"
         elif hour > 22:
             return "23:00"
-        return "%02d:00", hour - 1 if hour % 2 == 0 else hour
+        return "%02d:00" % (hour - 1 if hour % 2 == 0 else hour)
 
     def getMaxHm(self):
         hour = self.__lunar.getHour()
@@ -169,4 +169,4 @@ class LunarTime:
             return "00:59"
         elif hour > 22:
             return "23:59"
-        return "%02d:59", hour + 1 if hour % 2 != 0 else hour
+        return "%02d:59" % (hour + 1 if hour % 2 != 0 else hour)
